@@ -4,24 +4,24 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  2.213 qw(:Status createSelfTiedObject);
+use IO::Compress::Base::Common  2.214 qw(:Status createSelfTiedObject);
 
-use IO::Uncompress::Base  2.213 ;
-use IO::Uncompress::Adapter::LZO  2.213 ;
+use IO::Uncompress::Base  2.214 ;
+use IO::Uncompress::Adapter::LZO  2.214 ;
 use Compress::LZO qw(crc32 adler32);
-use IO::Compress::Lzop::Constants  2.213 ;
+use IO::Compress::Lzop::Constants  2.214 ;
 
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnLzopError);
 
-$VERSION = '2.213';
+$VERSION = '2.214';
 $UnLzopError = '';
 
 @ISA    = qw( IO::Uncompress::Base Exporter );
 @EXPORT_OK = qw( $UnLzopError unlzop ) ;
 #%EXPORT_TAGS = %IO::Uncompress::Base::EXPORT_TAGS ;
-push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
+$EXPORT_TAGS{all} = [ defined $EXPORT_TAGS{all} ? @{ $EXPORT_TAGS{all} } : (), @EXPORT_OK ] ;
 #Exporter::export_ok_tags('all');
 
 
@@ -1072,7 +1072,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2024 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2025 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
